@@ -149,7 +149,7 @@ sim3 <- function(lambda=4, gamma=0.1, omega=0.8, p=0.7, M=100, T=5)
     date[,1] <- 1
     for(i in 1:M) {
     for(t in 2:T) {
-        delta <- max(rpois(1, 3), 1)
+        delta <- max(rpois(1, 5), 1)
         date[i, t] <- date[i, t-1] + delta
         S[i, t-1] <- rbinom(1, N[i, t-1], omega)
         G[i, t-1] <- rpois(1, gamma)
@@ -175,7 +175,6 @@ sim3 <- function(lambda=4, gamma=0.1, omega=0.8, p=0.7, M=100, T=5)
 
 
 
-
 set.seed(373)
 nsim3 <- 100
 simout3 <- matrix(NA, nsim3, 4)
@@ -212,9 +211,26 @@ hist(simout3[,4], xlab=expression(p)); abline(v=p, lwd=2, col=4)
 dev.off()
 
 
+# v0.9-3
+#> summary(simout3)
+#     lambda          gamma            omega              p
+# Min.   :2.938   Min.   :0.1786   Min.   :0.6422   Min.   :0.4938
+# 1st Qu.:3.753   1st Qu.:0.2477   1st Qu.:0.7274   1st Qu.:0.6178
+# Median :4.225   Median :0.2840   Median :0.7471   Median :0.6676
+# Mean   :4.183   Mean   :0.2887   Mean   :0.7464   Mean   :0.6764
+# 3rd Qu.:4.589   3rd Qu.:0.3276   3rd Qu.:0.7749   3rd Qu.:0.7379
+# Max.   :5.770   Max.   :0.4769   Max.   :0.8343   Max.   :0.8915
 
 
-
+# v0.9-4
+#> summary(simout3)
+#     lambda           gamma            omega              p
+# Min.   : 2.513   Min.   :0.1321   Min.   :0.6100   Min.   :0.3015
+# 1st Qu.: 3.761   1st Qu.:0.1831   1st Qu.:0.7713   1st Qu.:0.5155
+# Median : 4.510   Median :0.2217   Median :0.8154   Median :0.6099
+# Mean   : 4.671   Mean   :0.2350   Mean   :0.8039   Mean   :0.6311
+# 3rd Qu.: 5.270   3rd Qu.:0.2771   3rd Qu.:0.8535   3rd Qu.:0.7302
+# Max.   :10.123   Max.   :0.4180   Max.   :0.9228   Max.   :0.9997
 
 
 
@@ -352,7 +368,7 @@ sim6 <- function(lambda=4, gamma=0.1, omega=0.8, p=0.7, M=100, T=5)
     y <- N <- date <- matrix(NA, M, T)
     S <- G <- matrix(NA, M, T-1)
     N[,1] <- rpois(M, lambda)
-    date[,1] <- pmax(rpois(M, 3), 1)
+    date[,1] <- pmax(rpois(M, 5), 1)
 
     for(i in 1:M) {
     if(date[i,1] > 1) {
@@ -412,6 +428,31 @@ hist(simout6[,4], xlab=expression(p)); abline(v=p, lwd=2, col=4)
 dev.off()
 
 
+#>   summary(simout6)
+#     lambda              gamma               omega
+# Min.   :7.235e-05   Min.   :2.084e-04   Min.   :6.247e-05
+# 1st Qu.:4.116e-01   1st Qu.:2.332e-01   1st Qu.:5.597e-01
+# Median :1.017e+00   Median :4.769e-01   Median :7.806e-01
+# Mean   :1.432e+00   Mean   :1.262e+00   Mean   :7.159e-01
+# 3rd Qu.:1.789e+00   3rd Qu.:8.638e-01   3rd Qu.:9.953e-01
+# Max.   :1.130e+01   Max.   :1.057e+01   Max.   :9.999e-01
+#       p
+# Min.   :0.004766
+# 1st Qu.:0.330542
+# Median :0.657263
+# Mean   :0.613498
+# 3rd Qu.:0.973869
+# Max.   :0.999867
+
+
+#> summary(simout6)
+#     lambda             gamma            omega              p
+# Min.   :0.001087   Min.   :0.2722   Min.   :0.6449   Min.   :0.5396
+# 1st Qu.:0.369777   1st Qu.:0.4154   1st Qu.:0.7728   1st Qu.:0.6475
+# Median :0.695017   Median :0.4741   Median :0.8080   Median :0.6933
+# Mean   :0.704249   Mean   :0.4751   Mean   :0.8046   Mean   :0.6928
+# 3rd Qu.:0.991107   3rd Qu.:0.5226   3rd Qu.:0.8476   3rd Qu.:0.7332
+# Max.   :1.859574   Max.   :0.6904   Max.   :0.9234   Max.   :0.8579
 
 
 
@@ -674,9 +715,9 @@ sim10 <- function(lam=c(0,1), gam=c(-1,-1), om=c(2,-1), p=c(-1,1), M=100,
     N <- N[,rep(1:T, each=J)]
     y[] <- rbinom(M*J*T, N, det)
     na.ind <- sample.int(M*J*T, nMissing)
-#    veght[na.ind<=M] <- NA
-#    isolation[na.ind<=(M*T)] <- NA
-#    time[na.ind] <- NA
+    veght[na.ind<=M] <- NA
+    isolation[na.ind<=(M*T)] <- NA
+    time[na.ind] <- NA
     covs <- data.frame(veght=veght, isolation=isolation, time=time)
     y[na.ind] <- NA
     return(list(y=y, covs=covs))
@@ -687,13 +728,14 @@ sim10 <- function(lam=c(0,1), gam=c(-1,-1), om=c(2,-1), p=c(-1,1), M=100,
 
 set.seed(4483499)
 nsim10 <- 100
-simout10 <- matrix(NA, nsim10, 8)
-colnames(simout10) <- c('lam0', 'lam1', 'gam0', 'gam1', 'om0', 'om1', 'p0', 'p1')
+simout10 <- matrix(NA, nsim10, 7)
+colnames(simout10) <- c('lam0', 'lam1', 'gam0', 'gam1', 'om0', #'om1',
+                        'p0', 'p1')
 for(i in 1:nsim10) {
     cat("sim10", i, "\n"); flush.console()
     lam <- c(-2, 1)
     gam <- c(-1, -1)
-    om <- c(0, -1)
+    om <- c(0, 0)
     p <- c(-1, 1)
     T <- 5
     sim10out <- sim10(lam, gam, om, p, T=T)
@@ -705,9 +747,9 @@ for(i in 1:nsim10) {
     obsCovs <- list(time = covs[,grep("time", cn)])
     umf10 <- unmarkedFramePCO(y = y.sim10, siteCovs=siteCovs,
         yearlySiteCovs=yearlySiteCovs, obsCovs=obsCovs, numPrimary=T)
-    m10 <- pcountOpen(~veght, ~isolation, ~isolation, ~time, umf10, K=30,
-                     se=F,
-        starts=c(lam, gam, om, p))
+    m10 <- pcountOpen(~veght, ~isolation, ~1, ~time, umf10, K=30,
+                      se=F, starts=c(lam, gam, 0, p),
+                      control=list(trace=F, REPORT=1))
     e <- coef(m10)
     simout10[i, ] <- e
     cat("  mle=", e, "\n")
@@ -726,10 +768,20 @@ hist(simout10[,8], xlab=expression(p)); abline(v=p[2], lwd=2, col=4)
 dev.off()
 
 
+m10 <- pcountOpen(~veght, ~1, ~1, ~time, umf10, K=30,
+                  se=F, #starts=c(0, 0, 0, p),
+                  control=list(trace=TRUE, REPORT=1))
 
 
 
 
+trace(unmarked:::handleNA, browser, browser, signature="unmarkedFramePCO")
+untrace(unmarked:::handleNA, signature="unmarkedFramePCO")
+
+
+debugonce(pcountOpen)
+
+
 
 ## Simulate "trend model", no covariates, constant intervals,
 ## no secondary samples
