@@ -33,7 +33,7 @@ SEXP nll_occu( SEXP yR, SEXP Xr, SEXP Vr, SEXP beta_psiR, SEXP beta_pR, SEXP ndR
     if(nd(i)==0)
       ll += log(cp * psi(i));
     else if(nd(i)==1)
-      ll += log(cp * psi(i) + (1-psi(i)));
+      ll += log(cp * psi(i) + (1-psi(i)) + DOUBLE_XMIN);
   }
   return wrap(-ll);
 }
